@@ -18,7 +18,7 @@ use Plack::Request;
 use Plack::Response;
 use Web::Solid::Auth::Listener;
 
-our $VERSION = "0.1";
+our $VERSION = "0.2";
 
 has webid => (
     is => 'ro' ,
@@ -173,43 +173,6 @@ sub make_access_token {
     return $data;
 }
 
-sub make_refresh_token {
-    my ($self) = @_;
-
-    my $access            = $self->get_access_token;
-
-    return undef unless $access->{refresh_token};
-
-    my $openid_conf       = $self->get_openid_configuration;
-    my $registration_conf = $self->get_client_configuration;
-
-    my $token_endpoint    = $openid_conf->{token_endpoint};
-    my $client_id         = $registration_conf->{client_id};
-
-    my $refresh_token     = $access->{refresh_token};
-
-    my $headers = $self->make_authentication_headers($token_endpoint,'POST');
-
-    $self->log->info("requesting refresh token at $token_endpoint using $refresh_token");
-
-    my $data = $self->post($token_endpoint, [
-        grant_type    => 'refresh_token' ,
-        refresh_token => $refresh_token ,
-        client_id     => $client_id ,
-        valid_for     => 300 ,
-    ], %$headers);
-
-    return undef unless $data;
-
-    my $cache_dir = $self->get_cache_dir;
-    path($cache_dir)->mkpath unless -d $cache_dir;
-
-    my $cache_file = path($cache_dir)->child("access.json")->stringify;
-    path($cache_file)->spew(encode_json($data));
-
-    return $data;
-}
-
 sub make_authentication_headers {
     my ($self, $uri, $method) = @_;
 
@@ -566,6 +529,7 @@ Web::Solid::Auth - A Perl Sold Web Client
 
 This is a Solid-OIDC implementation of a connection class for the Solid
 server. Use the C<bin/solid_auth.pl> command as a command line implementation.
+Check out the C<example> directory for a demo web application.
 
 =head1 CONFIGURATION
 
